/*
** Module   : TestPageHandler.java
** Abstract : delivers main page to tests
**
** Copyright (c) 2009-2013, Golden Code Development Corporation.
** ALL RIGHTS RESERVED. Use is subject to license terms.
**
**         Golden Code Development Corporation
**                 CONFIDENTIAL
**
** -#- -I- --Date-- ----------------------Description--------------------------
** 001 MAG 20131105 First version
*/

package com.goldencode.p2j.ws.test;

import java.util.logging.*;

import org.eclipse.jetty.server.*;

import com.goldencode.p2j.util.*;
import com.goldencode.p2j.ws.*;

/**
 * Jetty Handler which delivers HTML resource files.
 * This class provide a method to parse the HTML text and
 * substitute place holders. 
 */
public class TestPageHandler
extends HtmlResourceHandler
{
   /** Logger. */
   private static final Logger LOG = 
            LogHelper.getLogger(TestPageHandler.class.getName());
        
   /**
    * Constructor.
    *
    * @param    targetRoot
    *           Prefix for all URLs relating to this page.
    * @param    skeletonPage
    *           Fully qualified resource name of the HTML file which should be used.
    */
   public TestPageHandler(String targetRoot,
                          String skeletonPage)
   {
      super(targetRoot, skeletonPage);
      LOG.logp(Level.INFO,
               "TestPageHandler",
               "",
               LogHelper.generate("target=%s page=%s", 
                        targetRoot, skeletonPage));          
   }
   
         
   /**
    * Process the given string and make any replacements of parameter values
    * as needed. The replacement placeholder follow the JEE expression
    * language (EL) format for immediate evaluation format. 
    * Example: ${variable} 
    *
    * @param    base
    *           The details and state the request.
    * @param    text
    *           The text line that may need modifications.
    *
    * @return   The new text if a modification occurred or the original text
    *           if no modification was needed.
    */
   protected String handleReplacements(Request base, String text)
   {
      if(text.contains("${hostname}"))
      {
         text = text.replace("${hostname}", base.getServerName());
         text = text.replace("${port}", String.valueOf(base.getServerPort()));
         text = text.replace("${context}", base.getContextPath());
      }
      
      return text;
   }
         
}
