/*
 ** Module   : TestWsClient.java
 ** Abstract : A WebSocket client used for tests.
 **
 ** Copyright (c) 2009-2013, Golden Code Development Corporation.
 ** ALL RIGHTS RESERVED. Use is subject to license terms.
 **
 **         Golden Code Development Corporation
 **                 CONFIDENTIAL
 **
 ** -#- -I- --Date-- ----------------------Description--------------------------
 ** 001 MAG 20131105 First version based on jetty 9.1 web sockets
 */

package com.goldencode.p2j.ws.test;

import com.goldencode.p2j.cfg.*;
import com.goldencode.p2j.ws.*;

public class TestWsClient
implements WsClient
{

   /** Embedded server instance */
   protected WsServer wsServer = new WsServer();

   /**
    * Embedded jetty server startup.
    * 
    * @param   config
    *          The bootstrap configuration structure used to build
    *          the server HTTPS SSL context.
    *          If <b>null</b> the server SSL context is used as default.
    *  
    * @throws  Exception
    *          If an error condition occur during the server startup.  
    */   
   public void startup(BootstrapConfig config) throws Exception
   {
      // Create a main page Handler
      TestPageHandler mainPage = new TestPageHandler(
               "/page",
               "/com/goldencode/p2j/ws/test/index.html");
      // Configure and start the embedded server
      wsServer.setBootstrapConfig(config);
      wsServer.setContextPath("/client");
      wsServer.addHandler(mainPage);
      wsServer.addWsHandler("/test", TestWsServlet.class);
      /* use 0 as port number for dynamic allocation 
       * or use an alternate constructor */
      wsServer.startup("localhost", 8443);
      
   }

   /**
    * Embedded jetty server shutdown.
    *  
    * @throws  Exception
    *          If an error condition occur during the server shutdown.  
    */
   public void shutdown() throws Exception
   {
      wsServer.shutdown();
   }
   
}
