/*
 ** Module   : TestWsServlet.java
 ** Abstract : A WebSocket used for tests.
 **
 ** Copyright (c) 2009-2013, Golden Code Development Corporation.
 ** ALL RIGHTS RESERVED. Use is subject to license terms.
 **
 **         Golden Code Development Corporation
 **                 CONFIDENTIAL
 **
 ** -#- -I- --Date-- ----------------------Description--------------------------
 ** 001 MAG 20131105 First version based on jetty 9.1 web sockets
 */

package com.goldencode.p2j.ws.test;

import java.io.*;

import org.eclipse.jetty.websocket.api.*;
import org.eclipse.jetty.websocket.api.annotations.*;

/**
 * A simple WebSocket class POJO designed. 
 * 
 * Methods to create Web Sockets:
 * 1. POJO - Using WebSocket annotations.
 * 2. Implements WebSocketListener interface.
 * 3. Extends WebSocketAdapter class.
 */
@WebSocket
public class TestWsServlet
{
   private RemoteEndpoint remote;

   @OnWebSocketConnect
   public void onConnect(Session session)
   {
      System.out.println("WebSocket Opened");
      this.remote = session.getRemote();
   }

   @OnWebSocketMessage
   public void onMessage(String message)
   {
      System.out.println("Message from Client: " + message);
      try
      {
         remote.sendString("Hi Client");
      }
      catch (IOException e)
      {
         e.printStackTrace();
      }
   }

   @OnWebSocketClose
   public void onClose(int statusCode, String reason)
   {
      System.out.println("WebSocket Closed. Code:" + statusCode);
   }

   @OnWebSocketError
   public void onError(Session session, Throwable error)
   {
      System.out.println(error.getMessage());
   }

}